==> jtyoui-19.6.4-py3-none-any.whl: jtyoui/data/province.py <==
#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/3/14 17:59
# @Author: Jtyoui

Municipality_Directly_Under_The_Central_Government = ['北京市', '上海市', '天津市', '重庆市']  # 直辖市

# 安徽
AnHui = ['合肥', '安庆', '蚌埠', '亳州', '巢湖', '池州', '滁州', '阜阳', '淮北', '淮南', '黄山', '六安', '马鞍山', '宿州', '铜陵', '芜湖', '宣城']

# 福建
FuJian = ['福州', '龙岩', '南平', '宁德', '莆田', '泉州', '三明', '厦门', '漳州']

# 甘肃
GanSu = ['兰州', '白银', '定西', '甘南州', '嘉峪关', '金昌', '酒泉', '临夏州', '平凉', '庆阳', '天水', '武威', '张掖']

# 广东
GuangDong = ['广州', '潮州', '东莞', '佛山', '河源', '惠州', '江门', '揭阳', '茂名', '梅州', '清远', '汕头', '汕尾', '韶关', '深圳', '阳江', '云浮', '湛江',
             '肇庆', '中山', '珠海']

# 广西
GuangXi = ['南宁', '百色', '北海', '崇左', '防城港', '桂林', '贵港', '河池', '贺州', '来宾', '柳州', '钦州', '梧州', '玉林']

# 贵州
GuiZhou = ['贵阳', '安顺', '毕节地区', '六盘水', '铜仁地区', '遵义', '黔西南州']

# 海南
HaiNan = ['海口', '白沙', '保亭', '昌江', '儋州', '澄迈', '东方', '定安', '琼海', '琼中', '乐东', '临高', '陵水', '三亚', '屯昌', '万宁', '文昌', '五指山']

# 河北
HeBei = ['石家庄', '保定', '沧州', '承德', '邯郸', '衡水', '廊坊', '秦皇岛', '唐山', '邢台', '张家口']

# 河南
HeNan = ['郑州', '安阳', '鹤壁', '焦作', '开封', '洛阳', '漯河', '南阳', '平顶山', '濮阳', '三门峡', '商丘', '新乡', '信阳', '许昌', '周口', '驻马店']

# 黑龙江
HeiLongJiang = ['哈尔滨', '大庆', '大兴安岭地区', '鹤岗', '黑河', '鸡西', '佳木斯', '牡丹江', '七台河', '齐齐哈尔', '双鸭山', '绥化', '伊春']

# 湖北
HuBei = ['武汉', '鄂州', '恩施', '黄冈', '黄石', '荆门', '荆州', '潜江', '神农架林区', '十堰', '随州', '天门', '仙桃', '咸宁', '襄樊', '孝感', '宜昌']

# 湖南
HuNan = ['长沙', '常德', '郴州', '衡阳', '怀化', '娄底', '邵阳', '湘潭', '益阳', '永州', '岳阳', '张家界', '株洲']

# 江苏
JiangSu = ['南京', '常州', '淮安', '连云港', '南通', '苏州', '宿迁', '泰州', '无锡', '徐州', '盐城', '扬州', '镇江']

# 江西
JiangXi = ['南昌', '抚州', '赣州', '吉安', '景德镇', '九江', '萍乡', '上饶', '新余', '宜春', '鹰潭']

# 吉林
JiLin = ['长春', '白城', '白山', '吉林市', '辽源', '四平', '松原', '通化', '延边']

# 辽宁
LiaoNing = ['沈阳', '鞍山', '本溪', '朝阳', '大连', '丹东', '抚顺', '阜新', '葫芦岛', '锦州', '辽阳', '盘锦', '铁岭', '营口']

# 内蒙古
Inner_Mongolia = ['呼和浩特', '包头', '巴彦淖尔', '赤峰', '鄂尔多斯', '呼伦贝尔', '通辽', '乌海', '乌兰察布', '兴安盟']

# 宁夏
NingXia = ['银川', '固原', '石嘴山', '吴忠', '中卫']

# 青海
QingHai = ['西宁', '果洛州', '海东地区', '海北州', '海南州', '海西州', '黄南州', '玉树州']

# 山东
ShanDong = ['济南', '滨州', '东营', '德州', '菏泽', '济宁', '莱芜', '聊城', '临沂', '青岛', '日照', '泰安', '威海', '潍坊', '烟台', '枣庄', '淄博']

# 山西
ShanXi = ['太原', '长治', '大同', '晋城', '晋中', '临汾', '吕梁', '朔州', '忻州', '阳泉', '运城']

# 陕西
ShaAnXi = ['西安', '安康', '宝鸡', '汉中', '商洛', '铜川', '渭南', '咸阳', '延安', '榆林']

# 四川
SiChuan = ['成都', '阿坝州', '巴中', '达州', '德阳', '甘孜州', '广安', '广元', '乐山', '凉山州', '泸州', '南充', '眉山', '绵阳', '内江', '攀枝花', '遂宁',
           '雅安', '宜宾', '资阳', '自贡']

# 西藏
TiBet = ['拉萨', '阿里地区', '昌都地区', '林芝地区', '那曲地区', '日喀则地区', '山南地区']

# 新疆
XinJiang = ['乌鲁木齐', '阿拉尔', '阿克苏地区', '阿勒泰地区', '昌吉州', '哈密地区', '和田地区', '喀什地区', '克拉玛依', '石河子', '塔城地区', '吐鲁番地区']

# 云南
YunNan = ['昆明', '保山', '楚雄州', '大理州', '德宏州', '迪庆州', '红河州', '丽江', '临沧', '怒江州', '普洱', '曲靖', '昭通', '文山', '西双版纳', '玉溪']

# 浙江
ZheJiang = ['杭州', '湖州', '嘉兴', '金华', '丽水', '宁波', '衢州', '绍兴', '台州', '温州', '舟山']

Special_Administrative_Region = ['香港', '澳门', '台湾']  # 三个特别行政区

# 省
Province = ['安徽省', '福建省', '甘肃省', '广东省', '广西壮族自治区', '贵州省', '海南省', '河北省', '河南省', '黑龙江省',
            '台湾省', '内蒙古自治区', '宁夏回族自治区', '青海省', '山东省', '山西省', '陕西省', '四川省', '西藏自治区',
            '浙江省', '辽宁省' '江苏省', '江西省''新疆维吾尔自治区', '云南省', '湖北省', '湖南省']

# 全国
Whole_Country = [AnHui, FuJian, GanSu, GuangDong, GuangXi, GuiZhou, HaiNan, HeBei, HeNan, HeiLongJiang, HuBei, HuNan,
                 JiangSu, JiangXi, JiLin, LiaoNing, Inner_Mongolia, NingXia, QingHai, ShanDong, ShanXi, ShaAnXi,
                 SiChuan, TiBet, XinJiang, YunNan, ZheJiang]

==> jtyoui-2020.1.16-py3-none-any.whl: jtyoui/data/province.py <==
#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/3/14 17:59
# @Author: Jtyoui

Municipality_Directly_Under_The_Central_Government = ['北京市', '上海市', '天津市', '重庆市']  # 直辖市

# 安徽
AnHui = ['合肥', '安庆', '蚌埠', '亳州', '巢湖', '池州', '滁州', '阜阳', '淮北', '淮南', '黄山', '六安', '马鞍山', '宿州', '铜陵', '芜湖', '宣城']

# 福建
FuJian = ['福州', '龙岩', '南平', '宁德', '莆田', '泉州', '三明', '厦门', '漳州']

# 甘肃
GanSu = ['兰州', '白银', '定西', '甘南州', '嘉峪关', '金昌', '酒泉', '临夏州', '平凉', '庆阳', '天水', '武威', '张掖']

# 广东
GuangDong = ['广州', '潮州', '东莞', '佛山', '河源', '惠州', '江门', '揭阳', '茂名', '梅州', '清远', '汕头', '汕尾', '韶关', '深圳', '阳江', '云浮', '湛江',
             '肇庆', '中山', '珠海']

# 广西
GuangXi = ['南宁', '百色', '北海', '崇左', '防城港', '桂林', '贵港', '河池', '贺州', '来宾', '柳州', '钦州', '梧州', '玉林']

# 贵州
GuiZhou = ['贵阳', '安顺', '毕节地区', '六盘水', '铜仁地区', '遵义', '黔西南州']

# 海南
HaiNan = ['海口', '白沙', '保亭', '昌江', '儋州', '澄迈', '东方', '定安', '琼海', '琼中', '乐东', '临高', '陵水', '三亚', '屯昌', '万宁', '文昌', '五指山']

# 河北
HeBei = ['石家庄', '保定', '沧州', '承德', '邯郸', '衡水', '廊坊', '秦皇岛', '唐山', '邢台', '张家口']

# 河南
HeNan = ['郑州', '安阳', '鹤壁', '焦作', '开封', '洛阳', '漯河', '南阳', '平顶山', '濮阳', '三门峡', '商丘', '新乡', '信阳', '许昌', '周口', '驻马店']

# 黑龙江
HeiLongJiang = ['哈尔滨', '大庆', '大兴安岭地区', '鹤岗', '黑河', '鸡西', '佳木斯', '牡丹江', '七台河', '齐齐哈尔', '双鸭山', '绥化', '伊春']

# 湖北
HuBei = ['武汉', '鄂州', '恩施', '黄冈', '黄石', '荆门', '荆州', '潜江', '神农架林区', '十堰', '随州', '天门', '仙桃', '咸宁', '襄樊', '孝感', '宜昌']

# 湖南
HuNan = ['长沙', '常德', '郴州', '衡阳', '怀化', '娄底', '邵阳', '湘潭', '益阳', '永州', '岳阳', '张家界', '株洲']

# 江苏
JiangSu = ['南京', '常州', '淮安', '连云港', '南通', '苏州', '宿迁', '泰州', '无锡', '徐州', '盐城', '扬州', '镇江']

# 江西
JiangXi = ['南昌', '抚州', '赣州', '吉安', '景德镇', '九江', '萍乡', '上饶', '新余', '宜春', '鹰潭']

# 吉林
JiLin = ['长春', '白城', '白山', '吉林市', '辽源', '四平', '松原', '通化', '延边']

# 辽宁
LiaoNing = ['沈阳', '鞍山', '本溪', '朝阳', '大连', '丹东', '抚顺', '阜新', '葫芦岛', '锦州', '辽阳', '盘锦', '铁岭', '营口']

# 内蒙古
Inner_Mongolia = ['呼和浩特', '包头', '巴彦淖尔', '赤峰', '鄂尔多斯', '呼伦贝尔', '通辽', '乌海', '乌兰察布', '兴安盟']

# 宁夏
NingXia = ['银川', '固原', '石嘴山', '吴忠', '中卫']

# 青海
QingHai = ['西宁', '果洛州', '海东地区', '海北州', '海南州', '海西州', '黄南州', '玉树州']

# 山东
ShanDong = ['济南', '滨州', '东营', '德州', '菏泽', '济宁', '莱芜', '聊城', '临沂', '青岛', '日照', '泰安', '威海', '潍坊', '烟台', '枣庄', '淄博']

# 山西
ShanXi = ['太原', '长治', '大同', '晋城', '晋中', '临汾', '吕梁', '朔州', '忻州', '阳泉', '运城']

# 陕西
ShaAnXi = ['西安', '安康', '宝鸡', '汉中', '商洛', '铜川', '渭南', '咸阳', '延安', '榆林']

# 四川
SiChuan = ['成都', '阿坝州', '巴中', '达州', '德阳', '甘孜州', '广安', '广元', '乐山', '凉山州', '泸州', '南充', '眉山', '绵阳', '内江', '攀枝花', '遂宁',
           '雅安', '宜宾', '资阳', '自贡']

# 西藏
TiBet = ['拉萨', '阿里地区', '昌都地区', '林芝地区', '那曲地区', '日喀则地区', '山南地区']

# 新疆
XinJiang = ['乌鲁木齐', '阿拉尔', '阿克苏地区', '阿勒泰地区', '昌吉州', '哈密地区', '和田地区', '喀什地区', '克拉玛依', '石河子', '塔城地区', '吐鲁番地区']

# 云南
YunNan = ['昆明', '保山', '楚雄州', '大理州', '德宏州', '迪庆州', '红河州', '丽江', '临沧', '怒江州', '普洱', '曲靖', '昭通', '文山', '西双版纳', '玉溪']

# 浙江
ZheJiang = ['杭州', '湖州', '嘉兴', '金华', '丽水', '宁波', '衢州', '绍兴', '台州', '温州', '舟山']

Special_Administrative_Region = ['香港', '澳门', '台湾']  # 三个特别行政区

# 省
Province = ['安徽省', '福建省', '甘肃省', '广东省', '广西壮族自治区', '贵州省', '海南省', '河北省', '河南省', '黑龙江省',
            '台湾省', '内蒙古自治区', '宁夏回族自治区', '青海省', '山东省', '山西省', '陕西省', '四川省', '西藏自治区',
            '浙江省', '辽宁省' '江苏省', '江西省', '新疆维吾尔自治区', '云南省', '湖北省', '湖南省']

# 全国
Whole_Country = [AnHui, FuJian, GanSu, GuangDong, GuangXi, GuiZhou, HaiNan, HeBei, HeNan, HeiLongJiang, HuBei, HuNan,
                 JiangSu, JiangXi, JiLin, LiaoNing, Inner_Mongolia, NingXia, QingHai, ShanDong, ShanXi, ShaAnXi,
                 SiChuan, TiBet, XinJiang, YunNan, ZheJiang]
